libbluray-sys 1.0.0

Low level rust bindings to the libbluray library, optionally with libaacs / libbdplus support.
docs.rs failed to build libbluray-sys-1.0.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

libbluray-sys

This crate provides low level rust bindings to the libbluray library, optionally with libaacs / libbdplus support. You need to have the libraries already installed on your system in order to compile this crate. NOTE: This repository does not contain any keys or certificates to defeat copy protection.